@@ -3,7 +3,7 @@ from typing import List, Optional
 from uuid import UUID, uuid4
 
 from pydantic import BaseModel, HttpUrl
-from sqlmodel import Column, Field, Index, JSON, Relationship, String, SQLModel
+from sqlmodel import Column, Field, Index, JSON, Relationship, String, SQLModel, func
 
 from enum import Enum
 
@@ -157,9 +157,9 @@ class Article(SQLModel, table=True):
     parsed_content: "ParsedContent" = Relationship(back_populates="article")
 
 
-Index("ix_article_title", Article.summary, postgresql_using="gin")
-Index("ix_article_summary", Article.summary, postgresql_using="gin")
-Index("ix_article_authors", Article.summary, postgresql_using="gin")
+Index("ix_article_title", func.to_tsvector('english', Article.title), postgresql_using="gin")
+Index("ix_article_summary", func.to_tsvector('english', Article.summary), postgresql_using="gin")
+Index("ix_article_authors", func.to_tsvector('english', Article.authors), postgresql_using="gin")
 
 
 class RawContent(SQLModel, table=True):
@@ -170,7 +170,7 @@ class RawContent(SQLModel, table=True):
     article: Article = Relationship(back_populates="raw_content")
 
 
-Index("ix_rawcontent_content", RawContent.content, postgresql_using="gin")
+Index("ix_rawcontent_content", func.to_tsvector('english', RawContent.content), postgresql_using="gin")
 
 
 class ParsedContent(SQLModel, table=True):
@@ -181,21 +181,18 @@ class ParsedContent(SQLModel, table=True):
     article: Article = Relationship(back_populates="parsed_content")
 
 
-Index("ix_parsedcontent_content", ParsedContent.content, postgresql_using="gin")
+Index("ix_parsedcontent_content", func.to_tsvector('english', RawContent.content), postgresql_using="gin")
 
 
 class TermCount(SQLModel, table=True):
     article_id: UUID = Field(foreign_key="article.id", primary_key=True)
-    term: str = Field(primary_key=True, index=False)
+    term: str = Field(primary_key=True)
     count: int = Field(primary_key=True)
     added_at: datetime
 
     article: Article = Relationship(back_populates="term_counts")
 
 
-Index("ix_termcount_term", TermCount.term, postgresql_using="gin")
-
-
 class ArticleCluster(SQLModel, table=True):
     id: Optional[UUID] = Field(default_factory=uuid4, primary_key=True)
     # TODO enum? might be more trouble than it is worth
